@@ -1,9 +1,8 @@
 """This module provides implementations of various selection operators.
 """
-
-__all__ = ["APD_Select", "NSGAIII_select", "tour_select", "MOEAD_select"]
+__all__ = ["APD_Select", "NSGAIII_select", "TournamentSelection", "MOEAD_select"]
 
 from desdeo_emo.selection.APD_Select_constraints import APD_Select
 from desdeo_emo.selection.NSGAIII_select import NSGAIII_select
-from desdeo_emo.selection.tournament_select import tour_select
+from desdeo_emo.selection.TournamentSelection import TournamentSelection 
 from desdeo_emo.selection.MOEAD_select import MOEAD_select
